@@ -28,7 +28,6 @@ from alembic import config as alembic_config
 
 from barbican.common import config
 from barbican.common import utils
-from barbican import i18n as u
 
 LOG = utils.getLogger(__name__)
 
@@ -38,15 +37,15 @@ CONF = config.CONF
 
 def init_config(sql_url=None):
     """Initialize and return the Alembic configuration."""
-    sqlalchemy_url = sql_url or CONF.sql_connection
+    sqlalchemy_url = sql_url or CONF.database.connection
     if not sqlalchemy_url:
         raise RuntimeError("Please specify a SQLAlchemy-friendly URL to "
                            "connect to the proper database, either through "
                            "the CLI or the configuration file.")
 
     if sqlalchemy_url and 'sqlite' in sqlalchemy_url:
-        LOG.warning(u._('!!! Limited support for migration commands using'
-                        ' sqlite databases; This operation may not succeed.'))
+        LOG.warning('!!! Limited support for migration commands using'
+                    ' sqlite databases; This operation may not succeed.')
 
     config = alembic_config.Config(
         os.path.join(os.path.dirname(__file__), 'alembic.ini')
