@@ -36,7 +36,8 @@ def set_foreign_key_constraint(dbapi_connection, connection_record):
 
 def setup_in_memory_db():
     # Ensure we are using in-memory SQLite database, and creating tables.
-    repositories.CONF.set_override("sql_connection", "sqlite:///:memory:")
+    repositories.CONF.set_override("connection", "sqlite:///:memory:",
+                                   "database")
     repositories.CONF.set_override("db_auto_create", True)
     repositories.CONF.set_override("debug", True)
 
