@@ -704,14 +704,13 @@ class SecretsTestCase(base.TestCase):
             'payload_content_type': 'text/plain',
             'payload_content_encoding': None},
 
-        # TODO(dmend): Fix content negotiation
-        # 'utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain; charset=utf-8',
-        #    'payload_content_encoding': None},
+        'utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain; charset=utf-8',
+            'payload_content_encoding': None},
 
-        # 'no_space_utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain;charset=utf-8',
-        #    'payload_content_encoding': None},
+        'no_space_utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain;charset=utf-8',
+            'payload_content_encoding': None},
 
         'octet_content_type_base64_encoding': {
             'payload_content_type': 'application/octet-stream',
@@ -746,14 +745,13 @@ class SecretsTestCase(base.TestCase):
             'payload_content_type': 'text/plain',
             'payload_content_encoding': None},
 
-        # TODO(dmend): Fix content negotiation
-        # 'utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain; charset=utf-8',
-        #    'payload_content_encoding': None},
+        'utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain; charset=utf-8',
+            'payload_content_encoding': None},
 
-        # 'no_space_utf8_text_content_type_none_encoding': {
-        #    'payload_content_type': 'text/plain;charset=utf-8',
-        #    'payload_content_encoding': None},
+        'no_space_utf8_text_content_type_none_encoding': {
+            'payload_content_type': 'text/plain;charset=utf-8',
+            'payload_content_encoding': None},
 
         'octet_content_type_base64_encoding': {
             'payload_content_type': 'application/octet-stream',
